PluginManager

Struct PluginManager 

pub struct PluginManager { /* private fields */ }
Manager for all plugin runtimes and loaded plugins.

Implementations

Source

impl PluginManager

pub fn new(config: PluginConfig) -> Self

Create a new plugin manager with the given configuration.

pub fn register_runtime( &mut self, runtime: Box<dyn PluginRuntime>, ) -> PluginResult<()>

Register a plugin runtime.

pub fn get_runtime(&self, name: &str) -> Option<&dyn PluginRuntime>

Get a runtime by name.

pub fn get_runtime_mut( &mut self, name: &str, ) -> Option<&mut Box<dyn PluginRuntime>>

Get a mutable runtime by name.

pub fn init_runtimes(&mut self) -> PluginResult<()>

Initialize all registered runtimes.

pub async fn discover_plugins(&mut self) -> PluginResult<Vec<LoadedPlugin>>

Discover and load plugins from the plugin directory.

pub fn load_plugin(&mut self, path: &Path) -> PluginResult<LoadedPlugin>

Load a single plugin from a path.

pub fn unload_plugin(&mut self, handle: PluginHandle) -> PluginResult<()>

Unload a plugin.

pub async fn dispatch_hook( &self, hook: &Hook, ctx: &HookContext, ) -> Vec<HookResult>

Dispatch a hook to all plugins that implement it.

pub fn plugins(&self) -> impl Iterator<Item = &LoadedPlugin>

Get all loaded plugins.

pub fn get_plugin(&self, handle: PluginHandle) -> Option<&LoadedPlugin>

Get a loaded plugin by handle.

pub fn plugins_of_kind( &self, kind: PluginKind, ) -> impl Iterator<Item = &LoadedPlugin>

Get plugins of a specific kind.

pub fn shutdown(&mut self) -> PluginResult<()>

Shutdown all runtimes.