Rhai plugin runtime implementation.
This module provides a Rhai scripting runtime as an alternative to Lua. Rhai has a Rust-like syntax that may be more familiar to Rust developers.
Structs
- Rhai
Runtime - Rhai plugin runtime.
Rhai plugin runtime implementation.
This module provides a Rhai scripting runtime as an alternative to Lua. Rhai has a Rust-like syntax that may be more familiar to Rust developers.