pub struct PluginManager { /* private fields */ }Expand description
Manager for all plugin runtimes and loaded plugins.
Implementations
Sourceimpl PluginManager
impl PluginManager
Sourcepub fn new(config: PluginConfig) -> Self
pub fn new(config: PluginConfig) -> Self
Create a new plugin manager with the given configuration.
Sourcepub fn register_runtime(
&mut self,
runtime: Box<dyn PluginRuntime>,
) -> PluginResult<()>
pub fn register_runtime( &mut self, runtime: Box<dyn PluginRuntime>, ) -> PluginResult<()>
Register a plugin runtime.
Sourcepub fn get_runtime(&self, name: &str) -> Option<&dyn PluginRuntime>
pub fn get_runtime(&self, name: &str) -> Option<&dyn PluginRuntime>
Get a runtime by name.
Sourcepub fn get_runtime_mut(
&mut self,
name: &str,
) -> Option<&mut Box<dyn PluginRuntime>>
pub fn get_runtime_mut( &mut self, name: &str, ) -> Option<&mut Box<dyn PluginRuntime>>
Get a mutable runtime by name.
Sourcepub fn init_runtimes(&mut self) -> PluginResult<()>
pub fn init_runtimes(&mut self) -> PluginResult<()>
Initialize all registered runtimes.
Sourcepub async fn discover_plugins(&mut self) -> PluginResult<Vec<LoadedPlugin>>
pub async fn discover_plugins(&mut self) -> PluginResult<Vec<LoadedPlugin>>
Discover and load plugins from the plugin directory.
Sourcepub fn load_plugin(&mut self, path: &Path) -> PluginResult<LoadedPlugin>
pub fn load_plugin(&mut self, path: &Path) -> PluginResult<LoadedPlugin>
Load a single plugin from a path.
Sourcepub fn unload_plugin(&mut self, handle: PluginHandle) -> PluginResult<()>
pub fn unload_plugin(&mut self, handle: PluginHandle) -> PluginResult<()>
Unload a plugin.
Sourcepub async fn dispatch_hook(
&self,
hook: &Hook,
ctx: &HookContext,
) -> Vec<HookResult>
pub async fn dispatch_hook( &self, hook: &Hook, ctx: &HookContext, ) -> Vec<HookResult>
Dispatch a hook to all plugins that implement it.
Sourcepub fn get_plugin(&self, handle: PluginHandle) -> Option<&LoadedPlugin>
pub fn get_plugin(&self, handle: PluginHandle) -> Option<&LoadedPlugin>
Get a loaded plugin by handle.
Sourcepub fn plugins_of_kind(
&self,
kind: PluginKind,
) -> impl Iterator<Item = &LoadedPlugin>
pub fn plugins_of_kind( &self, kind: PluginKind, ) -> impl Iterator<Item = &LoadedPlugin>
Get plugins of a specific kind.
Sourcepub fn shutdown(&mut self) -> PluginResult<()>
pub fn shutdown(&mut self) -> PluginResult<()>
Shutdown all runtimes.